@@ -3,7 +3,7 @@ import os
 import platform
 
 
-def open():
+def xopen():
     pre_path = os.path.expanduser("~/学而思直播/code/cache/")
 
     project_path = os.getcwd()
